==> haskell-xss-sanitize-0.3.6-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-BW9y5wahQ4ymg4eiYgjdr
key: xss-sanitize-0.3.6-BW9y5wahQ4ymg4eiYgjdr
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 6a9386765d8bb2916d3e7d81bacd8305
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.6.5/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-BW9y5wahQ4ymg4eiYgjdr
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    containers-0.6.0.1 css-text-0.1.3.0-LlBHo1ngVsF1sRnX9Z0aY3
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.6-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-5LZqv2tAFb13J9yrFUGCop
key: xss-sanitize-0.3.6-5LZqv2tAFb13J9yrFUGCop
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 44da87ee609f1d8531fee6f6ed447c6b
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.6.5/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-5LZqv2tAFb13J9yrFUGCop
depends:
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    containers-0.6.0.1 css-text-0.1.3.0-FODfLfGK8mPDfLEhntFYo0
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    tagsoup-0.14.8-TxxcffRINhDkf2zJaQ0gs text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
